The code to run this benchmark entry is documented in `VKI_study.ipynb`.

### List of dependencies

- [PLAID=0.1.6](https://github.com/PLAID-lib/plaid)
- [GPy=1.13.2](https://github.com/SheffieldML/GPy)